An endpoint that sends a random image and fact of an animal
An endpoint that sends random things related to anime
An endpoint for generating images manipulated using Canvas
An endpoint for interactiong with the ChatBot
A struct with functions used for interacting with Some Random API
An endpoint that sends a random fact of an animal
An endpoint that sends a random image of an animal
An endpoint that sends other random stuff
An endpoint that sends Pokemon information
An endpoint for premium users
An endpoint for generating free welcome images